iotools.remove_abjad___pycache___directories
============================================

.. autofunction:: abjad.tools.iotools.remove_abjad___pycache___directories.remove_abjad___pycache___directories
